@@ -31,7 +31,7 @@ typedef struct CoverNode {
  * A placeholder for the linked list with file coverage information.
  */
 typedef struct CoverList {
-  CoverNode **list;
+  CoverNode** list;
   unsigned int used;
   unsigned int size;
 } CoverList;
@@ -50,7 +50,7 @@ void cover_destroy(CoverList* cover);
  * Add an executed file:line to the CoverList; will create CoverNode
  * for file, if it doesn't already exist.
  */
-void cover_add_covered(CoverList* cover, const char* file, int line);
+void cover_add_covered(CoverList* cover, const char* file, int line, int phase);
 
 /*
  * Add a file:line to the CoverList; will create CoverNode for file, if it
