@@ -2,10 +2,10 @@ package Devel::QuickCover;
 
 use strict;
 use warnings;
-
+use Carp 'croak';
 use XSLoader;
 
-our $VERSION = '0.600100';
+our $VERSION = '0.700000';
 
 XSLoader::load( 'Devel::QuickCover', $VERSION );
 
@@ -13,7 +13,7 @@ my %DEFAULT_CONFIG = (
     noatexit         => 0,      # Don't register an atexit handler to dump and cleanup
     nostart          => 0,      # Don't start gathering coverage information on import
     nodump           => 0,      # Don't dump the coverage report at the END of the program
-    output_directory => "/tmp", # Write report to that directory
+    output_directory => '/tmp', # Write report to that directory
     metadata         => {}    , # Additional context information
 );
 our %CONFIG;
@@ -21,7 +21,8 @@ our %CONFIG;
 sub import {
     my ($class, @opts) = @_;
 
-    die "Invalid argument to import, it takes key-value pairs. FOO => BAR" if 1 == @opts % 2;
+    croak('Invalid argument to import, it takes key-value pairs. FOO => BAR')
+        if 1 == @opts % 2;
     my %options = @opts;
 
     %CONFIG = %DEFAULT_CONFIG;
@@ -32,7 +33,7 @@ sub import {
     }
 
     if (keys %options > 0) {
-        die "Invalid import option(s): " . join(',', keys %options) ;
+        croak('Invalid import option(s): ' . join ',', keys %options);
     }
 
     if (!$CONFIG{'nostart'}) {
@@ -72,7 +73,7 @@ Devel::QuickCover - Quick & dirty code coverage for Perl
 
 =head1 VERSION
 
-Version 0.600100
+Version 0.700000
 
 =head1 SYNOPSIS
 
